<?php declare(strict_types=1);

/*
 * Plugin Name: Cxense list widget
 * Description: Display a list of articles from cxense list
 * Version: 0.1.0
 * Author: Infomaker Scandinavia AB
 * Author URI: https://infomaker.se
 */

namespace Everyware\Plugin\Cxense\Widgets;

use Everyware\ProjectPlugin\Components\Adapters\WidgetAdapter;
use Everyware\ProjectPlugin\Components\ComponentSettingsRepository;
use Everyware\ProjectPlugin\Components\Contracts\Admin;
use Everyware\ProjectPlugin\Components\SettingsProviders\SimpleSettingsProvider;
use Everyware\ProjectPlugin\Components\WidgetAdmin;
use Everyware\ProjectPlugin\Helpers\FileReader;
use Everyware\Plugin\Cxense\Api;
use Infomaker\Everyware\Twig\View;

class ListWidget extends WidgetAdapter
{
    /**
     * @var array
     */
    protected static $fields = [
        'title' => '',
        'widget_id' => '',
    ];

    protected static $settings ;

    protected $api;

    public static function setSettings($settings)
    {
        static::$settings = $settings;
    }

    protected function widgetSetup(): Admin
    {
        $api_url = static::$settings->getValue('api_url');
        $this->api = new Api($api_url);

        return new WidgetAdmin(
            new ListForm(new FileReader(__FILE__), $api_url),
            new ComponentSettingsRepository(new SimpleSettingsProvider(static::$fields))
        );
    }

    /**
     * @param array $viewData
     * @param array $args
     *
     * @return string
     */
    protected function generateWidget(array $viewData, array $args): string
    {
        return View::generate('@cxense/widgets/list/widget', array_replace($viewData, [
            'articles' => $this->getCxenseArticles($viewData)
        ]));
    }

    protected function getCxenseArticles(array $viewData)
    {
        $widget_id = $viewData['widget_id'] ?? null;

        if (!$this->api->getUrl() OR !$widget_id) {
          return [];
        }

        return $this->api->setQuery(['widgetId' => $widget_id])->get();
    }
}
